@@ -43,7 +43,7 @@
 using namespace Cpp;
 using namespace KDevelop;
 
-const int maxParentDepth = 20;
+const uint maxParentDepth = 20;
 
 namespace Cpp {
 
@@ -94,7 +94,7 @@ uint buildIdentifierForType(AbstractType::Ptr type, IndexedTypeIdentifier& id, u
     uint maxPointerLevel = buildIdentifierForType(pointerType->baseType(), id, pointerLevel, top);
     if(type->modifiers() & AbstractType::ConstModifier)
       id.setIsConstPointer(maxPointerLevel - pointerLevel, true);
-    if(id.pointerDepth() < pointerLevel)
+    if(static_cast<uint>(id.pointerDepth()) < pointerLevel)
       id.setPointerDepth(pointerLevel);
     
     return maxPointerLevel;
@@ -219,7 +219,7 @@ KDevelop::QualifiedIdentifier namespaceScopeComponentFromContext(QualifiedIdenti
   return prefix;
 }
 
-Declaration* localClassFromCodeContext(DUContext* context)
+Declaration* localClassFromCodeContext(const DUContext* context)
 {
   if(!context)
     return 0;
@@ -263,7 +263,7 @@ Declaration* localClassFromCodeContext(DUContext* context)
   return 0;
 }
 
-Declaration* localFunctionFromCodeContext(DUContext* context)
+Declaration* localFunctionFromCodeContext(const DUContext* context)
 {
   while( context->parentContext() && context->type() == DUContext::Other && context->parentContext()->type() == DUContext::Other )
   { //Move context to the top context of type "Other". This is needed because every compound-statement creates a new sub-context.
@@ -615,11 +615,10 @@ AbstractType::Ptr stripType(KDevelop::AbstractType::Ptr type, DUContext* ctx) {
           currentId.clearTemplateIdentifiers();
           
           KDevelop::InstantiationInformation instantiationInfo = tempDecl->instantiatedWith().information();
-          int neededParameters = 0;
           KDevelop::InstantiationInformation newInformation(instantiationInfo);
           newInformation.templateParametersList().clear();
           
-          for(neededParameters = 0; neededParameters < instantiationInfo.templateParametersSize(); ++neededParameters) {
+          for(uint neededParameters = 0; neededParameters < instantiationInfo.templateParametersSize(); ++neededParameters) {
             newInformation.templateParametersList().append(instantiationInfo.templateParameters()[neededParameters]);
             AbstractType::Ptr niceParam = stripType(instantiationInfo.templateParameters()[neededParameters].abstractType(), ctx);
             if(niceParam) {
@@ -637,18 +636,17 @@ AbstractType::Ptr stripType(KDevelop::AbstractType::Ptr type, DUContext* ctx) {
         }else{
           newTypeName = decl->qualifiedIdentifier();
         }
-
         //Strip unneded prefixes of the scope
-        while(newTypeName.count() > 1) {
-          KDevelop::QualifiedIdentifier candidate = newTypeName.mid(1);
+        KDevelop::QualifiedIdentifier candidate = newTypeName;
+        while(candidate.count() > 1) {
+          candidate = candidate.mid(1);
           QList< KDevelop::Declaration* > decls = ctx->findDeclarations(candidate);
           if(decls.isEmpty())
-            break;
-          if(decls[0]->kind() != Declaration::Type || decls[0]->indexedType() != type->indexed())
+            continue; // type aliases might be available for nested sub scopes, hence we must not break early
+          if(decls[0]->kind() != Declaration::Type || TypeUtils::removeConstModifier(decls[0]->indexedType()) != TypeUtils::removeConstModifier(type->indexed()))
             break;
           newTypeName = candidate;
         }
-        
         if(newTypeName == decl->qualifiedIdentifier())
           return type;
         
@@ -703,11 +701,9 @@ IndexedTypeIdentifier shortenedTypeIdentifier(AbstractType::Ptr type, DUContext*
 {
 
   bool isReference = false;
-  bool isConstReference = false;
-  if(type.cast<ReferenceType>()) {
+  if(ReferenceType::Ptr refType = type.cast<ReferenceType>()) {
     isReference = true;
-    isConstReference = type.cast<ReferenceType>()->modifiers() & AbstractType::ConstModifier;
-    type = type.cast<ReferenceType>()->baseType();
+    type = refType->baseType();
   }
 
   type = shortenTypeForViewing(type);
@@ -723,11 +719,8 @@ IndexedTypeIdentifier shortenedTypeIdentifier(AbstractType::Ptr type, DUContext*
     identifier = type.cast<DelayedType>()->identifier();
   identifier = stripPrefixIdentifiers(identifier, stripPrefix);
 
-  if(isReference) {
+  if(isReference)
     identifier.setIsReference(true);
-    if(isConstReference)
-      identifier.setIsConstant(true);
-  }
   
 //   if(identifier.toString().length() > desiredLength)
 //     identifier = Cpp::unTypedefType(decl, identifier);
@@ -795,9 +788,7 @@ QualifiedIdentifier stripPrefixes(DUContext* ctx, QualifiedIdentifier id)
 {
   if(!ctx)
     return id;
-  
-  QualifiedIdentifier basicId = id;
-  
+
   QList<QualifiedIdentifier> imports = ctx->fullyApplyAliases(QualifiedIdentifier(), ctx->topContext());
   if(imports.contains(id))
     return QualifiedIdentifier(); ///The id is a namespace that is imported into the current context
@@ -807,15 +798,16 @@ QualifiedIdentifier stripPrefixes(DUContext* ctx, QualifiedIdentifier id)
   if(basicDecls.isEmpty())
     return id;
   
-  while(!id.isEmpty())
+  QualifiedIdentifier newId = id.mid(1);
+  while(!newId.isEmpty())
   {
-    QualifiedIdentifier newId = id.mid(1);
     QList< Declaration* > foundDecls = ctx->findDeclarations(newId, CursorInRevision::invalid(), AbstractType::Ptr(), 0, (DUContext::SearchFlags)(DUContext::NoSelfLookUp | DUContext::NoFiltering));
-    
+
     if(foundDecls == basicDecls)
-      id = newId;
-    else
-      break;
+      id = newId; // must continue to find the shortest possible identifier
+                  // esp. for cases where nested namespaces are used (e.g. using namespace a::b::c;)
+
+    newId = newId.mid(1);
   }
 
   return id;
