@@ -43,6 +43,7 @@
 #include "parser/parser.h"
 #include "parser/control.h"
 #include "parser/dumptree.h"
+#include "parser/memorypool.h"
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainpointer.h>
 #include <language/duchain/duchainlock.h>
@@ -472,11 +473,8 @@ void CPPInternalParseJob::run()
         DUChainWriteLocker lock(DUChain::lock());
       if(!parentJob()->keepDuchain() &&
         ((!parentJob()->masterJob()->wasUpdated(contentContext) && parentJob()->needUpdateEverything())
-          || !proxyContext)) {
-
-          foreach(const DUContext::Import& ctx, contentContext->importedParentContexts())
-            contentContext->removeImportedParentContext(ctx.context(0));
-          }
+          || !proxyContext))
+            contentContext->clearImportedParentContexts();
           ///@todo Make this possible without a permanent write-lock
           contentContext->updateImportsCache();
     }
@@ -594,7 +592,7 @@ void CPPInternalParseJob::run()
 
       bool isStandardContext = false;
       {
-        DUChainWriteLocker l(DUChain::lock());
+        DUChainReadLocker l(DUChain::lock());
         TopDUContext* knownStandardContext = DUChainUtils::standardContextForUrl(parentJob()->document().toUrl());
 
         isStandardContext = (parentJob()->masterJob() == parentJob() || knownStandardContext == updatingContentContext || !knownStandardContext);
@@ -811,7 +809,7 @@ void CPPInternalParseJob::run()
           Q_ASSERT(0); //Failure
         }
 
-        Q_ASSERT(contentContextFromProxyContext(proxyContext) == contentContext.data());
+        Q_ASSERT(DUChainUtils::contentContextFromProxyContext(proxyContext) == contentContext.data());
 
         //Make sure the imported contextsa re added
         foreach ( const LineContextPair &context, parentJob()->includedFiles() )
