@@ -134,6 +134,13 @@ void CodeGenerator::visitBinaryExpression(BinaryExpressionAST* node)
   visit(node->right_expression);
 }
 
+void CodeGenerator::visitBracedInitList(BracedInitListAST* node)
+{
+  m_output << "{";
+  visit(node->list);
+  m_output << "}";
+}
+
 void CodeGenerator::visitCastExpression(CastExpressionAST* node)
 {
   m_output << "(";
@@ -340,15 +347,21 @@ void CodeGenerator::visitForStatement(ForStatementAST* node)
 {
   printToken(Token_for);
   m_output << "(";
-  if (node->init_statement) {
-    visit(node->init_statement);
-    // Init statement gives its own ;
+  if (node->range_declaration) {
+    visit(node->range_declaration);
+    m_output << " : ";
   } else {
+    if (node->init_statement) {
+      visit(node->init_statement);
+      // Init statement gives its own ;
+    } else {
+      m_output << ";";
+    }
+
+    visit(node->condition);
     m_output << ";";
   }
 
-  visit(node->condition);
-  m_output << ";";
   visit(node->expression);
   m_output << ")";
   visit(node->statement);
@@ -364,7 +377,7 @@ void CodeGenerator::visitFunctionCall(FunctionCallAST* node)
 void CodeGenerator::visitFunctionDefinition(FunctionDefinitionAST* node)
 {
   visit(node->type_specifier);
-  visit(node->init_declarator);
+  visit(node->declarator);
   visit(node->constructor_initializers);
   visit(node->function_body);
   visit(node->win_decl_specifiers);
@@ -411,13 +424,14 @@ void CodeGenerator::visitInitializer(InitializerAST* node)
 
 void CodeGenerator::visitInitializerClause(InitializerClauseAST* node)
 {
-  if (node->initializer_list) {
-    m_output << "{";
-    visitCommaPrint(node->initializer_list);
-    m_output << "}";
+  visit(node->expression);
+}
 
-  } else {
-    visit(node->expression);
+void CodeGenerator::visitInitializerList(InitializerListAST* node)
+{
+  visitCommaPrint(node->clauses);
+  if (node->isVariadic) {
+    m_output << "...";
   }
 }
 
@@ -612,8 +626,7 @@ void CodeGenerator::visitPtrOperator(PtrOperatorAST* node)
 
 void CodeGenerator::visitPtrToMember(PtrToMemberAST* node)
 {
-  // TODO fix AST
-  Q_UNUSED(node);
+  visit(node->class_type);
   printToken(Token_scope);
   m_output << "*";
 }
@@ -644,20 +657,25 @@ void CodeGenerator::visitSimpleTypeSpecifier(SimpleTypeSpecifierAST* node)
 
   print(node->integrals, true);
 
-  print(node->type_of);
-
   if (node->name) {
     visit(node->name);
     m_output << " ";
   }
 
-  if (node->type_id) {
-    m_output << "(";
-    visit(node->type_id);
+  if (node->isTypeof) {
+    m_output << "typeof";
+    ///TODO: expression in parens?
+    if (node->type_id) {
+      m_output << "(";
+      visit(node->type_id);
+      m_output << ")";
+    }
+    visit(node->expression);
+  } else if (node->isDecltype) {
+    m_output << "decltype(";
+    visit(node->expression);
     m_output << ")";
   }
-
-  visit(node->expression);
 }
 
 void CodeGenerator::visitSizeofExpression(SizeofExpressionAST* node)
