@@ -94,6 +94,7 @@ void TestParser::testVariadicTemplates_data()
                                                  "template<typename _Res, typename... _ArgTypes> struct is_function<_Res(_ArgTypes...) const> { };\n";
   QTest::newRow("pack-expansion-funcptr") << "template<typename ... Args> void foo(Args... args) { typedef int (*t5)(Args...); }\n";
   QTest::newRow("sizeof...") << "template<typename ... Arg> void A(Arg ... params) { int i = sizeof...(params); }\n";
+  QTest::newRow("template-template-param") << "template<template <typename> class... Magic> struct foo{};\n";
   ///TODO: attribute-list?
   ///TODO: alignment-specifier?
   ///TODO: capture-list?
@@ -540,3 +541,11 @@ void TestParser::classVirtSpec_data()
   QTest::newRow("explicit") <<
     QString("struct A explicit {};\n");
 }
+
+void TestParser::testUsingAlias()
+{
+  TranslationUnitAST* ast = parse( "using foo = bar; ");
+  QVERIFY(ast);
+  dump(ast);
+  QVERIFY(control.problems().isEmpty());
+}
\ No newline at end of file
