@@ -66,6 +66,7 @@ static char const * const _S_token_names[] = {
   "export",
   "extern",
   "false",
+  "final",
   "float",
   "for",
   "friend",
@@ -90,6 +91,7 @@ static char const * const _S_token_names[] = {
   "operator",
   "or",
   "or_eq",
+  "override",
   "preproc",
   "private",
   "protected",
@@ -182,6 +184,7 @@ static char const * const _S_token_texts[] = {
   "export",
   "extern",
   "false",
+  "final",
   "float",
   "for",
   "friend",
@@ -206,6 +209,7 @@ static char const * const _S_token_texts[] = {
   "operator",
   "||",
   "|=",
+  "override",
   "preproc",
   "private",
   "protected",
