@@ -64,6 +64,18 @@ public:
 
 private slots:
   void initTestCase();
+  void testCommentClearing();
+  void testExpressionBefore();
+  void testSpecialItems();
+  void testOnlyShow();
+  void testFriends();
+  void testInvalidContexts();
+  void testMemberAccess();
+  void testParentContexts();
+  void testCaseContext();
+  void testUnaryOperators();
+  void testBinaryOperators();
+  void testDeclarationIsInitialization();
   void testNoMemberAccess();
   void testFunctionImplementation();
   void testAliasDeclarationAccessPolicy();
@@ -125,7 +137,14 @@ private slots:
   void testFilterVoid();
   void testCompletedIncludeFilePath();
   void testMultipleIncludeCompletionItems();
-
+  void testParentConstructor_data();
+  void testParentConstructor();
+  void testOverride_data();
+  void testOverride();
+  void testExecuteKeepWord_data();
+  void testExecuteKeepWord();
+  void testAfterVisibility_data();
+  void testAfterVisibility();
 public:
   enum DumpArea {
     DumpNone = 0,
