@@ -56,6 +56,7 @@
 #include <kjob.h>
 
 #include "cmakeutils.h"
+#include <util/environmentgrouplist.h>
 
 using namespace KDevelop;
 
@@ -86,10 +87,10 @@ void CMakeJob::start()
 
     QString cmd = cmakeBinary( m_project );
     m_executor = new KDevelop::CommandExecutor(cmd, this);
-    connect(m_executor, SIGNAL(receivedStandardError(const QStringList&)),
-            model(), SLOT(appendLines(const QStringList&) ) );
-    connect(m_executor, SIGNAL(receivedStandardOutput(const QStringList&)),
-            model(), SLOT(appendLines(const QStringList&) ) );
+    connect(m_executor, SIGNAL(receivedStandardError(QStringList)),
+            model(), SLOT(appendLines(QStringList)) );
+    connect(m_executor, SIGNAL(receivedStandardOutput(QStringList)),
+            model(), SLOT(appendLines(QStringList)) );
     KUrl buildDirUrl = KUrl(QFileInfo(buildDir( m_project ).toLocalFile()).absoluteFilePath());
     if( !QFileInfo(buildDirUrl.toLocalFile()).exists() )
     {
@@ -99,8 +100,9 @@ void CMakeJob::start()
     }
     m_executor->setWorkingDirectory( buildDirUrl.toLocalFile() );
     m_executor->setArguments( cmakeArguments( m_project ) );
-    connect( m_executor, SIGNAL( failed(QProcess::ProcessError)), this, SLOT( slotFailed( QProcess::ProcessError ) ) );
-    connect( m_executor, SIGNAL( completed() ), this, SLOT( slotCompleted() ) );
+    m_executor->setEnvironment(buildEnvironment());
+    connect( m_executor, SIGNAL(failed(QProcess::ProcessError)), this, SLOT(slotFailed(QProcess::ProcessError)) );
+    connect( m_executor, SIGNAL(completed()), this, SLOT(slotCompleted()) );
     kDebug() << "Executing" << cmakeBinary( m_project ) << buildDirUrl.toLocalFile() << cmakeArguments( m_project );
     m_model->appendLine( buildDirUrl.toLocalFile() + "> " + cmakeBinary( m_project ) + " " + cmakeArguments( m_project ).join(" ") );
     m_executor->start();
@@ -148,36 +150,35 @@ QStringList CMakeJob::cmakeArguments( KDevelop::IProject* project )
     QStringList args;
     KUrl cmakecache = buildDir( project );
     cmakecache.addPath("CMakeCache.txt");
-    if( !QFileInfo( cmakecache.toLocalFile() ).exists() )
+    if( !CMake::currentInstallDir(project).toLocalFile().isEmpty() ) 
     {
-        if( !CMake::currentInstallDir(project).toLocalFile().isEmpty() ) 
-        {
-            args << QString("-DCMAKE_INSTALL_PREFIX=%1").arg(CMake::currentInstallDir(project).toLocalFile());
-        }
-        if( !CMake::currentBuildType(project).isEmpty() )
-        {
-            args << QString("-DCMAKE_BUILD_TYPE=%1").arg(CMake::currentBuildType(project));
-        }
-        if( !CMake::currentExtraArguments(project).isEmpty() ) {
-            KShell::Errors err;
-            QString cmakeargs = CMake::currentExtraArguments(project);
-            QStringList tmp = KShell::splitArgs( cmakeargs, KShell::TildeExpand | KShell::AbortOnMeta, &err );
-            if( err == KShell::NoError ) {
-                args += tmp;
+        args << QString("-DCMAKE_INSTALL_PREFIX=%1").arg(CMake::currentInstallDir(project).toLocalFile());
+    }
+    if( !CMake::currentBuildType(project).isEmpty() )
+    {
+        args << QString("-DCMAKE_BUILD_TYPE=%1").arg(CMake::currentBuildType(project));
+    }
+#ifdef Q_OS_WIN
+    // Visual Studio solution is the standard generator under windows, but we dont want to use
+    // the VS IDE, so we need nmake makefiles
+    args << QString("-G") << QString("NMake Makefiles");
+#endif
+    if( !CMake::currentExtraArguments(project).isEmpty() ) {
+        KShell::Errors err;
+        QString cmakeargs = CMake::currentExtraArguments(project);
+        QStringList tmp = KShell::splitArgs( cmakeargs, KShell::TildeExpand | KShell::AbortOnMeta, &err );
+        if( err == KShell::NoError ) {
+            args += tmp;
+        } else {
+            kWarning() << "Ignoring cmake Extra arguments";
+            if( err == KShell::BadQuoting ) {
+                kWarning() << "CMake arguments badly quoted:" << cmakeargs;
             } else {
-                kWarning() << "Ignoring cmake Extra arguments";
-                if( err == KShell::BadQuoting ) {
-                    kWarning() << "CMake arguments badly quoted:" << cmakeargs;
-                } else {
-                    kWarning() << "CMake arguments had meta character:" << cmakeargs;
-                }
+                kWarning() << "CMake arguments had meta character:" << cmakeargs;
             }
         }
-        args << CMake::projectRoot(project).toLocalFile();
-    } else 
-    {
-        args << ".";
     }
+    args << CMake::projectRoot(project).toLocalFile();
 
     return args;
 }
@@ -190,4 +191,14 @@ void CMakeJob::setProject(KDevelop::IProject* project)
         setObjectName(i18n("CMake: %1", m_project->name()));
 }
 
+QStringList CMakeJob::buildEnvironment()
+{
+    QString profile = CMake::currentEnvironment(m_project);
+
+    const KDevelop::EnvironmentGroupList l(KGlobal::config());
+    QStringList env = QProcess::systemEnvironment();
+    env.append( "LC_MESSAGES=C" );
+    return l.createEnvironment( profile, env );
+}
+
 #include "cmakejob.moc"
