@@ -26,6 +26,7 @@
 #include <QDomDocument>
 #include <QDir>
 #include <QQueue>
+#include <QThread>
 
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
@@ -95,8 +96,6 @@ using namespace KDevelop;
 K_PLUGIN_FACTORY(CMakeSupportFactory, registerPlugin<CMakeManager>(); )
 K_EXPORT_PLUGIN(CMakeSupportFactory(KAboutData("kdevcmakemanager","kdevcmake", ki18n("CMake Manager"), "0.1", ki18n("Support for managing CMake projects"), KAboutData::License_GPL)))
 
-Q_DECLARE_METATYPE ( KDevelop::ProjectFolderItem* )
-
 namespace {
 
 const QString DIALOG_CAPTION = i18n("KDevelop - CMake Support");
@@ -180,13 +179,16 @@ KTextEditor::Range rangeForText(KTextEditor::Document* doc, const KTextEditor::R
     QString txt=doc->text(r);
     QRegExp match("([\\s]|^)(\\./)?"+QRegExp::escape(name));
     int namepos = match.indexIn(txt);
+    int length = match.cap(0).size();
     
     if(namepos == -1)
         return KTextEditor::Range::invalid();
     //QRegExp doesn't support lookbehind asserts, and \b isn't good enough
     //so either match "^" or match "\s" and then +1 here
-    if (txt[namepos].isSpace())
+    if (txt[namepos].isSpace()) {
         ++namepos;
+        --length;
+    }
     
     KTextEditor::Cursor c(r.start());
     c.setLine(c.line() + txt.left(namepos).count('\n'));
@@ -196,7 +198,7 @@ KTextEditor::Range rangeForText(KTextEditor::Document* doc, const KTextEditor::R
     else
         c.setColumn(namepos - lastNewLinePos - 1);
     
-    return KTextEditor::Range(c, KTextEditor::Cursor(c.line(), c.column()+match.matchedLength()));
+    return KTextEditor::Range(c, KTextEditor::Cursor(c.line(), c.column()+length));
 }
 
 bool followUses(KTextEditor::Document* doc, RangeInRevision r, const QString& name, const KUrl& lists, bool add, const QString& replace)
@@ -437,6 +439,16 @@ CMakeFolderItem* nearestCMakeFolder(ProjectBaseItem* item)
     return dynamic_cast<CMakeFolderItem*>(item);
 }
 
+template<class T>
+QList<ProjectBaseItem*> castToBase(const QList<T*>& ptrs)
+{
+    QList<ProjectBaseItem*> ret;
+    foreach(ProjectBaseItem* ptr, ptrs)
+        ret += ptr;
+    
+    return ret;
+}
+
 }
 
 CMakeManager::CMakeManager( QObject* parent, const QVariantList& )
@@ -707,7 +719,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
         }*/
 
         QStringList alreadyAdded;
-        folder->cleanupBuildFolders(data.subdirectories);
+        deleteAllLater(castToBase(folder->cleanupBuildFolders(data.subdirectories)));
         foreach (const Subdirectory& subf, data.subdirectories)
         {
             if(subf.name.isEmpty() || alreadyAdded.contains(subf.name)) //empty case would not be necessary if we didn't process the wrong lines
@@ -732,7 +744,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                 if(ProjectFolderItem* ff = folder->folderNamed(subf.name))
                 {
                     if(ff->type()!=ProjectBaseItem::BuildFolder)
-                        delete ff;
+                        deleteItemLater(ff);
                     else
                         a = static_cast<CMakeFolderItem*>(ff);
                     
@@ -786,7 +798,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
 //             kDebug(9042) << "setting include directories: " << folder->url() << directories << "result: " << folder->includeDirectories();
         folder->setDefinitions(data.definitions);
 
-        folder->cleanupTargets(data.targets);
+        deleteAllLater(castToBase(folder->cleanupTargets(data.targets)));
         foreach ( const Target& t, data.targets)
         {
             QStringList files=t.files;
@@ -867,8 +879,8 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
         }
     } else if( folder ) {
         // Only do cmake-stuff if its a cmake folder
-        folder->cleanupBuildFolders(QList<Subdirectory>());
-        folder->cleanupTargets(QList<CMakeTarget>());
+        deleteAllLater(castToBase(folder->cleanupBuildFolders(QList<Subdirectory>())));
+        deleteAllLater(castToBase(folder->cleanupTargets(QList<CMakeTarget>())));
     } else {
         // Log non-cmake folders for debugging purposes
         kDebug(9042) << "Folder Item which is not a CMake folder parsed:" << item->url() << item->type();
@@ -893,7 +905,7 @@ void CMakeManager::setTargetFiles(ProjectTargetItem* target, const KUrl::List& f
     QList<ProjectFileItem*> tfiles = target->fileList();
     foreach(ProjectFileItem* file, tfiles) {
         if(!files.contains(file->url()))
-            target->removeRow(file->row());
+            deleteItemLater(file);
     }
     
     tfiles = target->fileList(); //We need to recreate the list without the removed items
@@ -1065,7 +1077,7 @@ void CMakeManager::cleanupToDelete(IProject* p)
     for(QSet<QString>::iterator it=m_toDelete.begin(), itEnd=m_toDelete.end(); it!=itEnd; ) {
         IndexedString url(*it);
         if(p->fileSet().contains(url)) {
-            qDeleteAll(p->filesForUrl(url.toUrl()));
+            deleteAllLater(castToBase(p->itemsForUrl(url.toUrl())));
             it=m_toDelete.erase(it);
         } else 
             ++it;
@@ -1223,12 +1235,13 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
         m_toDelete.remove(fileurl.toLocalFile());
         
         if(!entries.contains(current))
-            qDeleteAll(item->project()->itemsForUrl(fileurl));
+            deleteAllLater(item->project()->itemsForUrl(fileurl));
         else if(!it->url().equals(fileurl, KUrl::CompareWithoutTrailingSlash))
             it->setUrl(fileurl);
     }
     
     //We look for new elements
+    QList<ProjectBaseItem*> newItems;
     foreach( const QString& entry, entries )
     {
         KUrl fileurl = folderurl;
@@ -1243,18 +1256,22 @@ void CMakeManager::reloadFiles(ProjectFolderItem* item)
             ProjectFolderItem* pendingfolder = m_pending.take(fileurl);
             
             if(pendingfolder) {
-                item->appendRow(pendingfolder);
+                newItems += pendingfolder;
             } else if(isCorrectFolder(fileurl, item->project())) {
                 fileurl.adjustPath(KUrl::AddTrailingSlash);
+                ProjectFolderItem* it = new ProjectFolderItem( item->project(), fileurl, 0 );
+                reloadFiles(it);
                 m_watchers[item->project()]->addDir(fileurl.toLocalFile(), KDirWatch::WatchFiles);
-                reloadFiles(new ProjectFolderItem( item->project(), fileurl, item ));
+                newItems += it;
             }
         }
         else
         {
-            new KDevelop::ProjectFileItem( item->project(), fileurl, item );
+            newItems += new KDevelop::ProjectFileItem( item->project(), fileurl, 0 );
         }
     }
+    foreach(ProjectBaseItem* it, newItems)
+        item->appendRow(it);
 }
 
 bool CMakeManager::isCorrectFolder(const KUrl& url, IProject* p) const
@@ -1684,4 +1701,40 @@ void CMakeManager::projectClosing(IProject* p)
     m_watchers.remove(p);
 }
 
+void CMakeManager::addDeleteItem(ProjectBaseItem* item)
+{
+    if(item->parent() && item->model() && item->model()->thread()!=QThread::currentThread()) {
+        KDevelop::ProjectBaseItem* it = item->parent();
+        it->takeRow(item->row());
+        m_cleanupItems += item;
+    } else 
+        delete item;
+}
+
+void CMakeManager::deleteItemLater(ProjectBaseItem* item)
+{
+    addDeleteItem(item);
+    
+    if(!m_cleanupItems.isEmpty()) {
+        QMetaObject::invokeMethod(this, "cleanupItems", Qt::BlockingQueuedConnection);
+    }
+}
+
+void CMakeManager::deleteAllLater(const QList< ProjectBaseItem* >& items)
+{
+    foreach(KDevelop::ProjectBaseItem* item, items) {
+        addDeleteItem(item);
+    }
+    
+    if(!m_cleanupItems.isEmpty()) {
+        QMetaObject::invokeMethod(this, "cleanupItems", Qt::BlockingQueuedConnection);
+    }
+}
+
+void CMakeManager::cleanupItems()
+{
+    qDeleteAll(m_cleanupItems);
+    m_cleanupItems.clear();
+}
+
 #include "cmakemanager.moc"
